@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -41,7 +41,7 @@ unsigned GetModel3DAssetsLoadValue();
 // Cycle with function callback on each model3d asset load.
 void ForEachModel3DAssetLoad(std::function<void (unsigned AssetValue)> function);
 // Get preloaded model3d asset (preloaded by ForEachModel3DAssetLoad() call).
-std::weak_ptr<sModel3D> GetPreloadedModel3DAsset(const std::string &FileName);
+std::weak_ptr<sModel3D> GetPreloadedModel3DAsset(unsigned FileNameHash);
 
 } // astromenace namespace
 } // viewizard namespace
