@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -44,7 +44,7 @@ void ChangeTexturesAnisotropyLevel();
 // Get preloaded texture asset (preloaded by ForEachTextureAssetLoad() call).
 // Note, we don't validate textures, caller should care about call
 // ForEachTextureAssetLoad() each time, when this need.
-GLtexture GetPreloadedTextureAsset(const std::string &FileName);
+GLtexture GetPreloadedTextureAsset(unsigned FileNameHash);
 
 } // astromenace namespace
 } // viewizard namespace
