@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -341,4 +341,9 @@ void vw_RotatePointInv(sVECTOR3D &Point, const sVECTOR3D &Angle)
     }
 }
 
+unsigned hash_djb2a(const char *str, unsigned h)
+{
+    return !str[h] ? 5381 : (hash_djb2a(str, h + 1) * 33) ^ static_cast<unsigned>(str[h]);
+}
+
 } // viewizard namespace
