@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -460,7 +460,8 @@ void DrawMenu()
         && MenuStatus != eMenuStatus::OPTIONS
         && MenuStatus != eMenuStatus::CONFCONTROL
         && MenuStatus != eMenuStatus::OPTIONS_ADVANCED) {
-        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/astromenace.tga"), true, MenuContentTransp);
+        constexpr unsigned tmpHash = constexpr_hash_djb2a("menu/astromenace.tga");
+        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash), true, MenuContentTransp);
     }
 
     vw_End2DMode();
@@ -550,9 +551,9 @@ void DrawMenu()
     vw_DrawTextUTF32(6, GameConfig().InternalHeight - 16, 0, 0, 1.0f, sRGBCOLOR{eRGBCOLOR::white}, 0.99f, vw_GetTextUTF32("Version"));
     vw_DrawText(16 + VSize, GameConfig().InternalHeight - 16, 0, 0, 1.0f, sRGBCOLOR{eRGBCOLOR::white}, 0.99f, GAME_VERSION);
     // Copyright
-    int CSize = vw_TextWidth("Copyright © 2007-2022, Viewizard");
+    int CSize = vw_TextWidth("Copyright © 2007-2025, Viewizard");
     vw_DrawText(GameConfig().InternalWidth - 6 - CSize, GameConfig().InternalHeight - 16, 0, 0, 1.0f, sRGBCOLOR{eRGBCOLOR::white}, 0.99f,
-                "Copyright © 2007-2022, Viewizard");
+                "Copyright © 2007-2025, Viewizard");
 
     ResetFontSize();
     vw_End2DMode();
@@ -583,7 +584,8 @@ void DrawMenu()
 
         SrcRect(0, 0, 2, 2);
         DstRect(0, 0, GameConfig().InternalWidth, 768);
-        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/blackpoint.tga"), true, MenuBlackTransp);
+        constexpr unsigned tmpHash = constexpr_hash_djb2a("menu/blackpoint.tga");
+        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash), true, MenuBlackTransp);
 
         vw_End2DMode();
     }
@@ -603,7 +605,8 @@ void DrawMenu()
 
         SrcRect(0, 0, 2, 2);
         DstRect(0, 0, GameConfig().InternalWidth, 768);
-        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/blackpoint.tga"), true, MenuBlackTransp);
+        constexpr unsigned tmpHash = constexpr_hash_djb2a("menu/blackpoint.tga");
+        vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash), true, MenuBlackTransp);
 
         vw_End2DMode();
     }
