@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -59,7 +59,7 @@ static bool ReservedKeys(int Key)
         // don't remove this code duplication for now, don't use "[[fallthrough]];" (since C++17)
         // or "[[gnu::fallthrough]];" here for supress GCC7 warnings, since this produce another
         // warnings on old compiller versions
-        vw_SetKeyStatus(Key, false);
+        vw_SetKeyReleased(Key);
         return true;
     case SDLK_F1:
     case SDLK_F2:
@@ -86,7 +86,7 @@ static bool ReservedKeys(int Key)
     case SDLK_F23:
     case SDLK_F24:
     case SDLK_PRINTSCREEN:
-        vw_SetKeyStatus(Key, false);
+        vw_SetKeyReleased(Key);
         return true;
     }
 
@@ -100,7 +100,9 @@ void CheckMouseKeysJoystickState()
     if (!isDialogBoxDrawing() && NeedCheck > 0) {
         // keyboard
         if ((NeedCheck > 0 && NeedCheck <= 6) || NeedCheck == 100) {
-            for (int k = 0; k < vw_GetKeyStateArraySize(); k++) {
+            int KeyStateArraySize = 0;
+            SDL_GetKeyboardState(&KeyStateArraySize);
+            for (int k = 0; k < KeyStateArraySize; k++) {
                 int i = SDL_GetKeyFromScancode((SDL_Scancode)k);
                 if (vw_GetKeyStatus(i) && !ReservedKeys(i) && SDL_GetKeyName(i)) {
                     switch (NeedCheck) {
@@ -128,7 +130,7 @@ void CheckMouseKeysJoystickState()
                         break;
                     }
 
-                    vw_SetKeyStatus(i, false);
+                    vw_SetKeyReleased(i);
                     NeedCheck = 0;
                 }
             }
@@ -187,7 +189,7 @@ void CheckMouseKeysJoystickState()
 
         // in case Esc button - prevent future checks
         if (vw_GetKeyStatus(SDLK_ESCAPE)) {
-            vw_SetKeyStatus(SDLK_ESCAPE, false);
+            vw_SetKeyReleased(SDLK_ESCAPE);
             NeedCheck = 0;
         }
     }
@@ -251,7 +253,8 @@ void ConfControlMenu(float ContentTransp, float &ButtonTransp1, float &LastButto
     sRECT SrcRect, DstRect;
     SrcRect(0, 0, 2, 2);
     DstRect(0, 0, GameConfig().InternalWidth, 768);
-    vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/blackpoint.tga"), true, 0.5f * ContentTransp);
+    constexpr unsigned tmpHash1 = constexpr_hash_djb2a("menu/blackpoint.tga");
+    vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash1), true, 0.5f * ContentTransp);
 
 
 
@@ -291,9 +294,11 @@ void ConfControlMenu(float ContentTransp, float &ButtonTransp1, float &LastButto
             }
         }
         if (GameConfig().JoystickDeadZone > i) {
-            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/perc.tga"), true, ContentTransp);
+            constexpr unsigned tmpHash2 = constexpr_hash_djb2a("menu/perc.tga");
+            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash2), true, ContentTransp);
         } else {
-            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/perc_none.tga"), true, ContentTransp);
+            constexpr unsigned tmpHash3 = constexpr_hash_djb2a("menu/perc_none.tga");
+            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash3), true, ContentTransp);
         }
     }
 
@@ -326,9 +331,11 @@ void ConfControlMenu(float ContentTransp, float &ButtonTransp1, float &LastButto
             }
         }
         if (GameConfig().ControlSensivity > i) {
-            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/perc.tga"), true, ContentTransp);
+            constexpr unsigned tmpHash4 = constexpr_hash_djb2a("menu/perc.tga");
+            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash4), true, ContentTransp);
         } else {
-            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset("menu/perc_none.tga"), true, ContentTransp);
+            constexpr unsigned tmpHash5 = constexpr_hash_djb2a("menu/perc_none.tga");
+            vw_Draw2D(DstRect, SrcRect, GetPreloadedTextureAsset(tmpHash5), true, ContentTransp);
         }
     }
 
