@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -104,9 +104,9 @@ bool NeedCheckCollision(const cObject3D &Object3D)
 /*
  * Load 3D model data.
  */
-void LoadObjectData(const std::string &FileName, cObject3D &Object3D)
+void LoadObjectData(unsigned FileNameHash, cObject3D &Object3D)
 {
-    std::weak_ptr<sModel3D> Model = GetPreloadedModel3DAsset(FileName);
+    std::weak_ptr<sModel3D> Model = GetPreloadedModel3DAsset(FileNameHash);
     auto sharedModel = Model.lock();
     if (!sharedModel) {
         return;
