@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -81,7 +81,8 @@ static void ApplyBrightness()
     AddToDrawBuffer(GameConfig().InternalWidth, 0.0f, 0.0f, 0.0f);
     AddToDrawBuffer(GameConfig().InternalWidth, GameConfig().InternalHeight, 0.0f, 1.0f);
 
-    GLtexture TileTexture = GetPreloadedTextureAsset("menu/whitepoint.tga");
+    constexpr unsigned tmpHash = constexpr_hash_djb2a("menu/whitepoint.tga");
+    GLtexture TileTexture = GetPreloadedTextureAsset(tmpHash);
     vw_BindTexture(0, TileTexture);
 
     float BrightnessF = 1.0f + (GameConfig().Brightness - 5) / 5.0f;
