@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -1101,7 +1101,7 @@ bool cSpaceShip::Update(float Time)
     if (!ShipShake.empty()) {
         ShipShake[0].Update(TimeDelta, [&] (const float ShakeIncrement,
                                             const sVECTOR3D &ShakeDirection,
-                                            const unsigned UNUSED(ShakeChunkNum)) {
+                                            [[gnu::unused, maybe_unused]] const unsigned ShakeChunkNum) {
             SetRotation(ShakeDirection ^ (ShakeIncrement * 50.0f));
         });
     }
