@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -48,8 +48,8 @@ private:
     sRGBCOLOR TextColor_{eRGBCOLOR::white};
 
 public:
-    cStopwatch(cStopwatch const&) = delete;
-    void operator = (cStopwatch const&) = delete;
+    cStopwatch(const cStopwatch &) = delete;
+    void operator = (const cStopwatch &) = delete;
 
     static cStopwatch &GetInstance()
     {
