@@ -2,7 +2,7 @@
 
     AstroMenace
     Hardcore 3D space scroll-shooter with spaceship upgrade possibilities.
-    Copyright (c) 2006-2019 Mikhail Kurinnoi, Viewizard
+    Copyright (C) 2006-2025 Mikhail Kurinnoi, Viewizard
 
 
     AstroMenace is free software: you can redistribute it and/or modify
@@ -53,8 +53,8 @@ private:
     std::u32string DrawStringUTF32_{};
 
 public:
-    cGameSpeed(cGameSpeed const&) = delete;
-    void operator = (cGameSpeed const&) = delete;
+    cGameSpeed(const cGameSpeed &) = delete;
+    void operator = (const cGameSpeed &) = delete;
 
     static cGameSpeed &GetInstance()
     {
